@@ -1,7 +1,6 @@
 import abc
 import pathlib
 from abc import abstractmethod
-from datetime import datetime
 from typing import Optional
 
 from google.auth.transport.requests import Request as GoogleRequest
@@ -47,10 +46,7 @@ class GoogleServiceAccountCredentials(Credentials):
     @property
     def token(self) -> str:
         """Validated Bearer token using these credentials."""
-        expiry: Optional[datetime] = getattr(self._credentials, "expiry", None)
-
-        # TODO: Check if expiry time is before `now()` and call `refresh()` again.
-        if not expiry:
+        if not self.credentials.valid:
             self.credentials.refresh(GoogleRequest())
 
         return self.credentials.token
