@@ -1,5 +1,7 @@
+from myst.connectors.operation_connectors.fill_na import FillNA
 from myst.connectors.operation_connectors.get_dummies import GetDummies
 from myst.connectors.operation_connectors.numerical_expression import NumericalExpression
+from myst.connectors.operation_connectors.resampling import Resampling
 from myst.connectors.operation_connectors.time_transformations import TimeTransformations
 
-__all__ = ["NumericalExpression", "TimeTransformations", "GetDummies"]
+__all__ = ["FillNA", "GetDummies", "NumericalExpression", "Resampling", "TimeTransformations"]
