@@ -144,10 +144,10 @@ class TimeDataset(BaseModel):
         example="PT1H", description="The sample period of the time dataset formatted as an ISO 8601 Duration string."
     )
     metadata: Optional[Metadata] = Field(
-        example={"key": "value"}, description="User-defined metadata about the time dataset."
+        None, example={"key": "value"}, description="User-defined metadata about the time dataset."
     )
     data: List[TimeDatasetRow] = Field(description="List of rows belonging to this time dataset.", min_items=1)
-    cell_shape: Shape = Field(None, example=(), description="The shape of each cell in the time dataset.")
+    cell_shape: Optional[Shape] = Field(example=(), description="The shape of each cell in the time dataset.")
 
     @validator("data")
     def ensure_unique_as_of_times(cls, v: List[TimeDatasetRow]) -> List[TimeDatasetRow]:
