@@ -2,11 +2,10 @@ from typing import Optional, Union
 
 import pydantic
 
-from myst.adapters.utils import UNSET
 from myst.core.time.time import Time
 from myst.core.time.time_delta import TimeDelta
 from myst.models.base_model import BaseModel
-from myst.models.types import OptionalParam
+from myst.models.types import OptionalArgument, Unset
 
 
 class Timing(BaseModel):
@@ -36,8 +35,8 @@ TimeRangeBoundary = Union[Time, TimeDelta, AbsoluteOrRelativeTiming]
 
 
 def from_time_range_boundary(
-    timing: OptionalParam[Union[Time, TimeDelta, AbsoluteOrRelativeTiming]]
-) -> OptionalParam[AbsoluteOrRelativeTiming]:
+    timing: OptionalArgument[Union[Time, TimeDelta, AbsoluteOrRelativeTiming]]
+) -> OptionalArgument[AbsoluteOrRelativeTiming]:
     """Returns the given argument as a timing appropriate for a time range boundary.
 
     If an `AbsoluteOrRelativeTiming`, `None` or `UNSET` is passed, it will be returned unchanged.
@@ -59,8 +58,8 @@ def from_time_range_boundary(
     """
     if timing is None or isinstance(timing, (AbsoluteTiming, RelativeTiming)):
         return timing
-    elif timing is UNSET:
-        return UNSET
+    elif isinstance(timing, Unset):
+        return timing
     elif isinstance(timing, Time):
         # Interpret as fixed point in time.
         return AbsoluteTiming(time=timing)
@@ -71,9 +70,15 @@ def from_time_range_boundary(
         raise TypeError("Argument must be of type `Time`, `TimeDelta, `Timing`, or None.")
 
 
-def from_schedule_specifier(timing: Union[Time, TimeDelta, ScheduleTiming]) -> ScheduleTiming:
+def from_schedule_specifier(
+    timing: OptionalArgument[Union[Time, TimeDelta, ScheduleTiming]]
+) -> OptionalArgument[Optional[ScheduleTiming]]:
     """Returns the given argument as a timing appropriate for scheduling.
 
+    If a `None` is passed, `None` will be returned.
+
+    If a `UNSET` is passed, `UNSET` will be returned.
+
     If a `Time` is passed, it will be interpreted as specifying a fixed point in time, and an `AbsoluteTiming` will
     be returned.
 
@@ -91,7 +96,11 @@ def from_schedule_specifier(timing: Union[Time, TimeDelta, ScheduleTiming]) -> S
     Raises:
         TypeError: if the argument is of a type that cannot be understood as a schedule timing
     """
-    if isinstance(timing, Time):
+    if timing is None:
+        return timing
+    elif isinstance(timing, Unset):
+        return timing
+    elif isinstance(timing, Time):
         return AbsoluteTiming(time=timing)
     elif isinstance(timing, TimeDelta):
         return RelativeTiming(frequency=timing)
