@@ -2,8 +2,12 @@ from functools import singledispatch
 from typing import Any, List, Mapping, Optional, Tuple, TypeVar, Union
 from uuid import UUID
 
-from myst.adapters.utils import _Unset
 
+class Unset:
+    pass
+
+
+UNSET = Unset()
 UUIDOrStr = Union[str, UUID]
 IntOrStr = Union[int, str]
 Shape = Tuple[int, ...]
@@ -11,13 +15,13 @@ CoordinateLabels = Tuple[Tuple[IntOrStr, ...], ...]
 AxisLabels = Tuple[IntOrStr, ...]
 Metadata = Mapping[str, Union[str, int, float, bool, None]]
 
-T = TypeVar("T")
-OptionalParam = Union[Optional[T], _Unset]
-
 # Note: This should be a recursive type alias but `mypy` doesn't support that, so use `List[Any]` instead to allow for
 #   an arbitrary amount of nesting.
 ItemOrSlice = Union[Tuple[Union[IntOrStr, List[Any]], ...], List[Any], IntOrStr]
 
+T = TypeVar("T")
+OptionalArgument = Union[Optional[T], Unset]
+
 
 @singledispatch
 def to_uuid(uuid: UUIDOrStr) -> UUID:
