@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.organization_get import OrganizationGet
+from myst.openapi.models.organization_get import OrganizationGet
 
 
 def request_sync(client: Client, uuid: str) -> OrganizationGet:
