@@ -1,7 +1,6 @@
 from myst.client import Client
-
-from ...models.project_get import ProjectGet
-from ...models.project_update import ProjectUpdate
+from myst.openapi.models.project_get import ProjectGet
+from myst.openapi.models.project_update import ProjectUpdate
 
 
 def request_sync(client: Client, uuid: str, json_body: ProjectUpdate) -> ProjectGet:
