@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.input_get import InputGet
+from myst.openapi.models.input_get import InputGet
 
 
 class InputList(base_model.BaseModel):
