@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.project_get import ProjectGet
+from myst.openapi.models.project_get import ProjectGet
 
 
 class ProjectList(base_model.BaseModel):
