@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.time_series_run_policy_get import TimeSeriesRunPolicyGet
+from myst.openapi.models.time_series_run_policy_get import TimeSeriesRunPolicyGet
 
 
 class TimeSeriesRunPolicyList(base_model.BaseModel):
