@@ -2,8 +2,7 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.organization_role import OrganizationRole
+from myst.openapi.models.organization_role import OrganizationRole
 
 
 class UserCreate(base_model.BaseModel):
