@@ -145,6 +145,7 @@ def example_model_input(example_model: Dict[str, Any]) -> Dict[str, Any]:
         create_time="2021-09-15T22:36:36Z",
         update_time=None,
         type="Input",
+        project=example_model["project"],
         downstream_node=example_model["uuid"],
         upstream_node="e6af86ed-850c-484d-898e-72a53b4ffe7f",
         output_index=0,
@@ -161,6 +162,7 @@ def example_operation_input(example_operation: Dict[str, Any]) -> Dict[str, Any]
         create_time="2021-09-15T22:36:31Z",
         update_time=None,
         type="Input",
+        project=example_operation["project"],
         downstream_node=example_operation["uuid"],
         upstream_node="d4d750fe-f727-4073-b6d9-8c643476ac93",
         output_index=0,
@@ -177,6 +179,7 @@ def example_layer(example_time_series: Dict[str, Any]) -> Dict[str, Any]:
         create_time="2021-09-15T22:36:44Z",
         update_time=None,
         type="Layer",
+        project=example_time_series["project"],
         downstream_node=example_time_series["uuid"],
         upstream_node="36cad5b7-6ea8-4e08-9546-d28218e2486f",
         output_index=0,
@@ -266,6 +269,19 @@ def example_result() -> Dict[str, Any]:
     )
 
 
+@pytest.fixture
+def example_deployment(example_project: Dict[str, Any]) -> Dict[str, Any]:
+    return dict(
+        object="Deployment",
+        project=example_project["uuid"],
+        uuid="3fa85f64-5717-4562-b3fc-2c963f66afa6",
+        create_time="2021-01-01T01:23:45Z",
+        title="My deployment",
+        activate_time="2021-01-01T01:23:45Z",
+        creator=example_project["creator"],
+    )
+
+
 @pytest.fixture
 def example_hpo_result() -> Dict[str, Any]:
     return dict(
