@@ -3,12 +3,12 @@ from typing import Any, Dict, List, Optional, Union
 from uuid import UUID
 
 from myst.adapters.timing import to_timing_create
-from myst.adapters.utils import UNSET, _Unset, drop_unset_values, get_resource_uuid
+from myst.adapters.utils import drop_unset_values, get_resource_uuid
 from myst.client import get_client
 from myst.core.time.time import Time
 from myst.models.base_model import BaseModel
 from myst.models.timing import AbsoluteOrCronTiming, CronTiming, TimeRangeBoundary, from_time_range_boundary
-from myst.models.types import OptionalParam, UUIDOrStr, to_uuid
+from myst.models.types import UNSET, OptionalArgument, Unset, UUIDOrStr, to_uuid
 from myst.openapi.api.projects.hpos import create_hpo, get_hpo, list_hpos, run_hpo, update_hpo
 from myst.openapi.models.hpo_create import HPOCreate
 from myst.openapi.models.hpo_job_state import HPOJobState
@@ -54,21 +54,19 @@ class Hyperopt(BaseModel):
     max_concurrent_trials: Optional[int] = 1
 
 
-def _to_search_algorithm_create(hyper_opt: OptionalParam[Hyperopt]) -> OptionalParam[SearchAlgorithmCreate]:
-    if hyper_opt is None:
-        return None
-    elif isinstance(hyper_opt, _Unset):
-        return UNSET
-    else:
+def _to_search_algorithm_create(hyper_opt: OptionalArgument[Hyperopt]) -> OptionalArgument[SearchAlgorithmCreate]:
+    if isinstance(hyper_opt, Hyperopt):
         return SearchAlgorithmCreate(object="SearchAlgorithm", **hyper_opt.dict())
+    else:
+        return hyper_opt
 
 
 def _to_search_space_create(
-    search_space: OptionalParam[Dict[str, Optional[Union[Uniform, QUniform, LogUniform, QLogUniform]]]]
-) -> OptionalParam[Dict[str, Optional[Union[UniformModel, QUniformModel, LogUniformModel, QLogUniformModel]]]]:
+    search_space: OptionalArgument[Dict[str, Optional[Union[Uniform, QUniform, LogUniform, QLogUniform]]]]
+) -> OptionalArgument[Dict[str, Optional[Union[UniformModel, QUniformModel, LogUniformModel, QLogUniformModel]]]]:
     if search_space is None:
         return None
-    elif isinstance(search_space, _Unset):
+    elif isinstance(search_space, Unset):
         return UNSET
 
     search_space_create: Dict[str, Optional[Union[UniformModel, QUniformModel, LogUniformModel, QLogUniformModel]]] = {}
@@ -158,32 +156,28 @@ class HPO(Resource):
 
     def update(
         self,
-        title: OptionalParam[str] = UNSET,
-        model: OptionalParam[Union[Model, UUIDOrStr]] = UNSET,
-        test_start_time: OptionalParam[Time] = UNSET,
-        test_end_time: OptionalParam[Time] = UNSET,
-        fit_start_timing: OptionalParam[TimeRangeBoundary] = UNSET,
-        fit_end_timing: OptionalParam[TimeRangeBoundary] = UNSET,
-        fit_reference_timing: OptionalParam[AbsoluteOrCronTiming] = UNSET,
-        predict_start_timing: OptionalParam[TimeRangeBoundary] = UNSET,
-        predict_end_timing: OptionalParam[TimeRangeBoundary] = UNSET,
-        predict_reference_timing: OptionalParam[CronTiming] = UNSET,
-        search_algorithm: OptionalParam[Hyperopt] = UNSET,
-        search_space: OptionalParam[Dict[str, Optional[Union[Uniform, QUniform, LogUniform, QLogUniform]]]] = UNSET,
-        description: OptionalParam[str] = UNSET,
+        title: OptionalArgument[str] = UNSET,
+        model: OptionalArgument[Union[Model, UUIDOrStr]] = UNSET,
+        test_start_time: OptionalArgument[Time] = UNSET,
+        test_end_time: OptionalArgument[Time] = UNSET,
+        fit_start_timing: OptionalArgument[TimeRangeBoundary] = UNSET,
+        fit_end_timing: OptionalArgument[TimeRangeBoundary] = UNSET,
+        fit_reference_timing: OptionalArgument[AbsoluteOrCronTiming] = UNSET,
+        predict_start_timing: OptionalArgument[TimeRangeBoundary] = UNSET,
+        predict_end_timing: OptionalArgument[TimeRangeBoundary] = UNSET,
+        predict_reference_timing: OptionalArgument[CronTiming] = UNSET,
+        search_algorithm: OptionalArgument[Hyperopt] = UNSET,
+        search_space: OptionalArgument[Dict[str, Optional[Union[Uniform, QUniform, LogUniform, QLogUniform]]]] = UNSET,
+        description: OptionalArgument[str] = UNSET,
     ) -> "HPO":
         """Updates an HPO."""
         hpo_update: Dict[str, Any] = dict(
             object="HPO",
             title=title,
             description=description,
-            model=model if model is None or isinstance(model, _Unset) else str(get_resource_uuid(model)),
-            test_start_time=test_start_time
-            if test_start_time is None or isinstance(test_start_time, _Unset)
-            else test_start_time.to_iso_string(),
-            test_end_time=test_end_time
-            if test_end_time is None or isinstance(test_end_time, _Unset)
-            else test_end_time.to_iso_string(),
+            model=str(get_resource_uuid(model)) if isinstance(model, Model) else model,
+            test_start_time=test_start_time.to_iso_string() if isinstance(test_start_time, Time) else test_start_time,
+            test_end_time=test_end_time.to_iso_string() if isinstance(test_end_time, Time) else test_end_time,
             fit_start_timing=to_timing_create(from_time_range_boundary(fit_start_timing)),
             fit_end_timing=to_timing_create(from_time_range_boundary(fit_end_timing)),
             fit_reference_timing=to_timing_create(fit_reference_timing),
