@@ -1,7 +1,8 @@
 from typing import TYPE_CHECKING, Union
 from uuid import UUID
 
-from myst.adapters.utils_test import get_resource_uuid
+from myst.adapters.utils import get_resource_uuid
+
 from myst.client import get_client
 from myst.models.types import UUIDOrStr
 from myst.openapi.api.projects.hpos.results import get_hpo_result
